aboutsummaryrefslogtreecommitdiff
path: root/libbuild2/target.hxx
diff options
context:
space:
mode:
authorKaren Arutyunov <karen@codesynthesis.com>2019-08-01 16:10:01 +0300
committerKaren Arutyunov <karen@codesynthesis.com>2019-08-01 16:41:08 +0300
commit8e69e09b7ec68377758c63092f9b254e95a0d7be (patch)
tree91f29f69c5a329d3a7e8594407e8a0330d146002 /libbuild2/target.hxx
parentcd090e741cdee437632554d22c5ae84572c7267f (diff)
Fix linkage failure due to inline functions defined in libbuild2/algorithm.ixx and referred from libbuild2/target.txx
Diffstat (limited to 'libbuild2/target.hxx')
-rw-r--r--libbuild2/target.hxx13
1 files changed, 8 insertions, 5 deletions
diff --git a/libbuild2/target.hxx b/libbuild2/target.hxx
index cfbd9bc..6d320d4 100644
--- a/libbuild2/target.hxx
+++ b/libbuild2/target.hxx
@@ -36,8 +36,11 @@ namespace build2
// From <libbuild2/algorithm.hxx>.
//
- const target& search (const target&, const prerequisite&);
- const target* search_existing (const prerequisite&);
+ LIBBUILD2_SYMEXPORT const target&
+ search (const target&, const prerequisite&);
+
+ LIBBUILD2_SYMEXPORT const target*
+ search_existing (const prerequisite&);
// Recipe.
//
@@ -278,7 +281,7 @@ namespace build2
public:
// Normally you should not call this function directly and rather use
- // resolve_members() from algorithm.hxx.
+ // resolve_members() from <libbuild2/algorithm.hxx>.
//
virtual group_view
group_members (action) const;
@@ -469,7 +472,7 @@ namespace build2
static size_t count_executed () {return offset_executed + count_base ();}
static size_t count_busy () {return offset_busy + count_base ();}
// Inner/outer operation state. See operation.hxx for details.
//
class LIBBUILD2_SYMEXPORT opstate
{
@@ -480,7 +483,7 @@ namespace build2
// operation. It is incremented during match and then decremented during
// execution, before running the recipe. As a result, the recipe can
// detect the last chance (i.e., last dependent) to execute the command
// (see also the first/last execution modes in <operation.hxx>).
//
mutable atomic_count dependents {0};
@@ -469,7 +472,7 @@ namespace build2
static size_t count_executed () {return offset_executed + count_base ();}
static size_t count_busy () {return offset_busy + count_base ();}
- // Inner/outer operation state. See operation.hxx for details.
+ // Inner/outer operation state. See <libbuild2/operation.hxx> for details.
//
class LIBBUILD2_SYMEXPORT opstate
@@ -480,7 +483,7 @@ namespace build2
// execution, before running the recipe. As a result, the recipe can
// detect the last chance (i.e., last dependent) to execute the command
- // (see also the first/last execution modes in <operation.hxx>).
+ // (see also the first/last execution modes in <libbuild2/operation.hxx>).
//
mutable atomic_count dependents {0};